@@ -1,8 +1,3 @@
-/* gdkconfig.h
- *
- * This is a generated file.  Please modify `configure.ac'
- */
-
 #ifndef __GDKCONFIG_H__
 #define __GDKCONFIG_H__
 
@@ -16,6 +11,12 @@ G_BEGIN_DECLS
 
 
 #define GDK_WINDOWING_X11
+#undef GDK_WINDOWING_BROADWAY
+#undef GDK_WINDOWING_WAYLAND
+#undef GDK_WINDOWING_WIN32
+/* #undef GDK_WINDOWING_MIR */
+
+#undef GDK_RENDERING_VULKAN
 
 G_END_DECLS
 
