@@ -28,7 +28,6 @@
 #define __GTK_A11Y_H_INSIDE__
 
 #include <gtk/gtk.h>
-#include <gtk/a11y/gtkarrowaccessible.h>
 #include <gtk/a11y/gtkbooleancellaccessible.h>
 #include <gtk/a11y/gtkbuttonaccessible.h>
 #include <gtk/a11y/gtkcellaccessible.h>
@@ -57,8 +56,8 @@
 #include <gtk/a11y/gtkmenushellaccessible.h>
 #include <gtk/a11y/gtknotebookaccessible.h>
 #include <gtk/a11y/gtknotebookpageaccessible.h>
-#include <gtk/a11y/gtkpopoveraccessible.h>
 #include <gtk/a11y/gtkpanedaccessible.h>
+#include <gtk/a11y/gtkpopoveraccessible.h>
 #include <gtk/a11y/gtkprogressbaraccessible.h>
 #include <gtk/a11y/gtkradiobuttonaccessible.h>
 #include <gtk/a11y/gtkradiomenuitemaccessible.h>
@@ -72,6 +71,7 @@
 #include <gtk/a11y/gtkstackaccessible.h>
 #include <gtk/a11y/gtkstatusbaraccessible.h>
 #include <gtk/a11y/gtkswitchaccessible.h>
+#include <gtk/a11y/gtktextaccessible.h>
 #include <gtk/a11y/gtktextcellaccessible.h>
 #include <gtk/a11y/gtktextviewaccessible.h>
 #include <gtk/a11y/gtktogglebuttonaccessible.h>
