@@ -51,14 +51,10 @@ G_BEGIN_DECLS
 
 typedef struct _GtkScaleButton        GtkScaleButton;
 typedef struct _GtkScaleButtonClass   GtkScaleButtonClass;
-typedef struct _GtkScaleButtonPrivate GtkScaleButtonPrivate;
 
 struct _GtkScaleButton
 {
-  GtkButton parent;
-
-  /*< private >*/
-  GtkScaleButtonPrivate *priv;
+  GtkButton parent_instance;
 };
 
 struct _GtkScaleButtonClass
@@ -79,8 +75,7 @@ struct _GtkScaleButtonClass
 GDK_AVAILABLE_IN_ALL
 GType            gtk_scale_button_get_type         (void) G_GNUC_CONST;
 GDK_AVAILABLE_IN_ALL
-GtkWidget *      gtk_scale_button_new              (GtkIconSize      size,
-                                                    gdouble          min,
+GtkWidget *      gtk_scale_button_new              (gdouble          min,
                                                     gdouble          max,
                                                     gdouble          step,
                                                     const gchar    **icons);
