@@ -218,18 +218,6 @@ void                   gtk_tree_view_set_model                     (GtkTreeView
 GDK_AVAILABLE_IN_ALL
 GtkTreeSelection      *gtk_tree_view_get_selection                 (GtkTreeView               *tree_view);
 
-GDK_DEPRECATED_IN_3_0_FOR(gtk_scrollable_get_hadjustment)
-GtkAdjustment         *gtk_tree_view_get_hadjustment               (GtkTreeView               *tree_view);
-GDK_DEPRECATED_IN_3_0_FOR(gtk_scrollable_set_hadjustment)
-void                   gtk_tree_view_set_hadjustment               (GtkTreeView               *tree_view,
-								    GtkAdjustment             *adjustment);
-GDK_DEPRECATED_IN_3_0_FOR(gtk_scrollable_get_vadjustment)
-GtkAdjustment         *gtk_tree_view_get_vadjustment               (GtkTreeView               *tree_view);
-GDK_DEPRECATED_IN_3_0_FOR(gtk_scrollable_set_vadjustment)
-void                   gtk_tree_view_set_vadjustment               (GtkTreeView               *tree_view,
-								    GtkAdjustment             *adjustment);
-
-
 GDK_AVAILABLE_IN_ALL
 gboolean               gtk_tree_view_get_headers_visible           (GtkTreeView               *tree_view);
 GDK_AVAILABLE_IN_ALL
@@ -242,14 +230,9 @@ gboolean               gtk_tree_view_get_headers_clickable         (GtkTreeView
 GDK_AVAILABLE_IN_ALL
 void                   gtk_tree_view_set_headers_clickable         (GtkTreeView               *tree_view,
 								    gboolean                   setting);
-GDK_DEPRECATED_IN_3_14
-void                   gtk_tree_view_set_rules_hint                (GtkTreeView               *tree_view,
-								    gboolean                   setting);
-GDK_DEPRECATED_IN_3_14
-gboolean               gtk_tree_view_get_rules_hint                (GtkTreeView               *tree_view);
-GDK_AVAILABLE_IN_3_8
+GDK_AVAILABLE_IN_ALL
 gboolean               gtk_tree_view_get_activate_on_single_click  (GtkTreeView               *tree_view);
-GDK_AVAILABLE_IN_3_8
+GDK_AVAILABLE_IN_ALL
 void                   gtk_tree_view_set_activate_on_single_click  (GtkTreeView               *tree_view,
 								    gboolean                   single);
 
@@ -279,7 +262,7 @@ gint                   gtk_tree_view_insert_column_with_data_func  (GtkTreeView
                                                                     gpointer                   data,
                                                                     GDestroyNotify             dnotify);
 
-GDK_AVAILABLE_IN_3_4
+GDK_AVAILABLE_IN_ALL
 guint                  gtk_tree_view_get_n_columns                 (GtkTreeView               *tree_view);
 GDK_AVAILABLE_IN_ALL
 GtkTreeViewColumn     *gtk_tree_view_get_column                    (GtkTreeView               *tree_view,
@@ -362,8 +345,6 @@ void                   gtk_tree_view_get_cursor                    (GtkTreeView
 
 /* Layout information */
 GDK_AVAILABLE_IN_ALL
-GdkWindow             *gtk_tree_view_get_bin_window                (GtkTreeView               *tree_view);
-GDK_AVAILABLE_IN_ALL
 gboolean               gtk_tree_view_get_path_at_pos               (GtkTreeView               *tree_view,
 								    gint                       x,
 								    gint                       y,
@@ -401,13 +382,11 @@ gboolean               gtk_tree_view_is_blank_at_pos               (GtkTreeView
 GDK_AVAILABLE_IN_ALL
 void                   gtk_tree_view_enable_model_drag_source      (GtkTreeView               *tree_view,
 								    GdkModifierType            start_button_mask,
-								    const GtkTargetEntry      *targets,
-								    gint                       n_targets,
+								    GdkContentFormats         *formats,
 								    GdkDragAction              actions);
 GDK_AVAILABLE_IN_ALL
 void                   gtk_tree_view_enable_model_drag_dest        (GtkTreeView               *tree_view,
-								    const GtkTargetEntry      *targets,
-								    gint                       n_targets,
+								    GdkContentFormats         *formats,
 								    GdkDragAction              actions);
 GDK_AVAILABLE_IN_ALL
 void                   gtk_tree_view_unset_rows_drag_source        (GtkTreeView               *tree_view);
@@ -431,7 +410,7 @@ gboolean               gtk_tree_view_get_dest_row_at_pos           (GtkTreeView
 								    GtkTreePath              **path,
 								    GtkTreeViewDropPosition   *pos);
 GDK_AVAILABLE_IN_ALL
-cairo_surface_t       *gtk_tree_view_create_row_drag_icon          (GtkTreeView               *tree_view,
+GdkPaintable          *gtk_tree_view_create_row_drag_icon          (GtkTreeView               *tree_view,
 								    GtkTreePath               *path);
 
 /* Interactive search */
@@ -454,10 +433,10 @@ void                       gtk_tree_view_set_search_equal_func (GtkTreeView
 								GDestroyNotify              search_destroy);
 
 GDK_AVAILABLE_IN_ALL
-GtkEntry                     *gtk_tree_view_get_search_entry         (GtkTreeView                   *tree_view);
+GtkEditable                  *gtk_tree_view_get_search_entry         (GtkTreeView                   *tree_view);
 GDK_AVAILABLE_IN_ALL
 void                          gtk_tree_view_set_search_entry         (GtkTreeView                   *tree_view,
-								      GtkEntry                      *entry);
+								      GtkEditable                   *entry);
 GDK_AVAILABLE_IN_ALL
 GtkTreeViewSearchPositionFunc gtk_tree_view_get_search_position_func (GtkTreeView                   *tree_view);
 GDK_AVAILABLE_IN_ALL
@@ -504,18 +483,6 @@ void gtk_tree_view_convert_bin_window_to_tree_coords   (GtkTreeView *tree_view,
 							gint        *tx,
 							gint        *ty);
 
-/* This function should really never be used.  It is just for use by ATK.
- */
-typedef void (* GtkTreeDestroyCountFunc)  (GtkTreeView             *tree_view,
-					   GtkTreePath             *path,
-					   gint                     children,
-					   gpointer                 user_data);
-GDK_DEPRECATED_IN_3_4
-void gtk_tree_view_set_destroy_count_func (GtkTreeView             *tree_view,
-					   GtkTreeDestroyCountFunc  func,
-					   gpointer                 data,
-					   GDestroyNotify           destroy);
-
 GDK_AVAILABLE_IN_ALL
 void     gtk_tree_view_set_fixed_height_mode (GtkTreeView          *tree_view,
 					      gboolean              enable);
